@@ -1,12 +1,13 @@
 from msgtools.database.influxdb import InfluxDBConnection
 from msgtools.lib.messaging import Messaging
 from PyQt5 import QtCore, QtGui, QtWidgets
+import time
 
 class InfluxServerPlugin(QtCore.QObject):
     statusUpdate = QtCore.pyqtSignal(str)
     messagereceived = QtCore.pyqtSignal(object)
     disconnected = QtCore.pyqtSignal(object)
-
+    
     def __init__(self, param):
         super(InfluxServerPlugin, self).__init__(None)
         
@@ -25,10 +26,17 @@ class InfluxServerPlugin(QtCore.QObject):
         self.subValue = 0
         self.isHardwareLink = False
         self.statusLabel = QtWidgets.QLabel("influxdb %s:%d" % (self.db.hostname, self.db.port))
+        self.summaryLabel = QtWidgets.QLabel(self.db.stats.report_stats(None, 1))
 
         self.removeClient = QtWidgets.QPushButton("Remove")
         self.removeClient.pressed.connect(self.onDisconnected)
 
+        # start a timer to print summary data peridically
+        self.display_timer = QtCore.QTimer(self)
+        self.display_timer.setInterval(1000)
+        self.display_timer.timeout.connect(self.print_summary)
+        self.display_timer.start()
+
     def onDisconnected(self):
         self.disconnected.emit(self)
 
@@ -37,6 +45,8 @@ class InfluxServerPlugin(QtCore.QObject):
             return self.removeClient
         if index == 1:
             return self.statusLabel
+        if index == 2:
+            return self.summaryLabel
         return None
 
     def start(self):
@@ -53,6 +63,10 @@ class InfluxServerPlugin(QtCore.QObject):
     # for influxdb telling us to send
     def send_message(self, hdr):
         self.messagereceived.emit(hdr)
+    
+    def print_summary(self):
+        stats = self.db.stats.report_stats(None, self.display_timer.interval() / 1000.0)
+        self.summaryLabel.setText(stats)
 
 def PluginConnection(param=""):
     isp = InfluxServerPlugin(param)
